@@ -62,21 +62,22 @@ function(x, ...)
     cat("\n")
     cat("GUM mean equation:\n")
     cat("\n")
-    printCoefmat(x$gum.mean, dig.tst=0, tst.ind=c(1,2))
-#OLD:    print(x$gum.mean)
+    printCoefmat(x$gum.mean, dig.tst=0, tst.ind=c(1,2),
+      signif.stars=FALSE, P.values=FALSE, has.Pvalue=FALSE)
   }
   if(!is.null(x$gum.variance)){
     cat("\n")
     cat("GUM log-variance equation:\n")
     cat("\n")
-    printCoefmat(x$gum.variance, dig.tst=0, tst.ind=c(1,2))
-#OLD:    print(x$gum.variance)
+    printCoefmat(x$gum.variance, dig.tst=0, tst.ind=c(1,2),
+      signif.stars=FALSE, P.values=FALSE, has.Pvalue=FALSE)
   }
   if(!is.null(x$gum.diagnostics)){
     cat("\n")
     cat("Diagnostics:\n")
     cat("\n")
-    printCoefmat(x$gum.diagnostics[1:3,], dig.tst=0, tst.ind=2)
+    printCoefmat(x$gum.diagnostics[1:3,], dig.tst=0, tst.ind=2,
+      signif.stars=FALSE)
   }
 
   ##paths:
@@ -101,8 +102,8 @@ function(x, ...)
     }
   }
   cat("\n")
-  printCoefmat(x$terminals.results, dig.tst=0, tst.ind=c(3,4))
-#OLD:  print(x$terminals.results)
+  printCoefmat(x$terminals.results, dig.tst=0, tst.ind=c(3,4),
+    signif.stars=FALSE)
 
   ##specific model:
   if(spec=="mean" && !is.null(x$specific.spec)){
@@ -110,8 +111,7 @@ function(x, ...)
     cat("SPECIFIC mean equation:\n")
     cat("\n")
     if(!is.null(x$mean.results)){
-      printCoefmat(x$mean.results)
-#OLD:      print(x$mean.results)
+      printCoefmat(x$mean.results, signif.stars=FALSE)
     }
     if(x$specific.spec[1]==0){
       cat("empty\n")
@@ -125,15 +125,14 @@ function(x, ...)
     cat("\n")
     cat("SPECIFIC log-variance equation:\n")
     cat("\n")
-    printCoefmat(x$variance.results)
-#OLD:    print(x$variance.results)
+    printCoefmat(x$variance.results, signif.stars=FALSE)
   }
   if(!is.null(x$specific.diagnostics)){
     cat("\n")
     cat("Diagnostics:\n")
     cat("\n")
-    printCoefmat(x$specific.diagnostics, dig.tst=0, tst.ind=2)
-#OLD:    print(x$specific.diagnostics)
+    printCoefmat(x$specific.diagnostics, dig.tst=0, tst.ind=2,
+      signif.stars=FALSE)
   }
 
   ##notes:
